@@ -5,9 +5,9 @@ from flask import Blueprint, Response, make_response, request
 from werkzeug.exceptions import HTTPException
 
 from fastadmin.api.exceptions import AdminApiException
-from fastadmin.api.helpers import get_user_id_from_session_id, is_valid_id
+from fastadmin.api.helpers import is_valid_id
 from fastadmin.api.schemas import ActionInputSchema, ExportInputSchema, SignInInputSchema
-from fastadmin.api.service import ApiService
+from fastadmin.api.service import ApiService, get_user_id_from_session_id
 from fastadmin.settings import settings
 
 logger = logging.getLogger(__name__)
