@@ -22,12 +22,12 @@ class PonyORMMixin:
     def get_model_fields_with_widget_types(
         self,
         with_m2m: bool | None = None,
+        with_upload: bool | None = None,
     ) -> list[ModelFieldWidgetSchema]:
         """This method is used to get model fields with widget types.
 
         :params with_m2m: a flag to include m2m fields.
-        :params with_pk: a flag to include pk fields.
-        :params with_readonly: a flag to include readonly fields.
+        :params with_upload: a flag to include upload fields.
         :return: A list of ModelFieldWidgetSchema.
         """
         orm_model_fields = [v for f, v in self.model_cls.__dict__.items() if not f.startswith("_")]
@@ -45,12 +45,15 @@ class PonyORMMixin:
                     field_type = "fk"
 
             is_m2m = field_type in "m2m"
-
+            is_upload = False
             if with_m2m is not None and not with_m2m and is_m2m:
                 continue
-
             if with_m2m is not None and with_m2m and not is_m2m:
                 continue
+            if with_upload is not None and not with_upload and is_upload:
+                continue
+            if with_upload is not None and with_upload and not is_upload:
+                continue
 
             is_pk = getattr(orm_model_field, "is_pk", False)
             is_immutable = (
@@ -349,6 +352,7 @@ class PonyORMMixin:
 
         :params obj: an object.
         :params field: a m2m field name.
+        :params ids: a list of ids.
 
         :return: A list of ids.
         """
@@ -364,6 +368,19 @@ class PonyORMMixin:
         flush()
         commit()
 
+    @sync_to_async
+    @db_session
+    def orm_save_upload_field(self, obj: Any, field: str, base64: str) -> None:
+        """This method is used to save upload field.
+
+        :params obj: an object.
+        :params field: a m2m field name.
+        :params base64: a base64 string.
+
+        :return: A list of ids.
+        """
+        pass
+
     @sync_to_async
     @db_session
     def serialize_obj_attributes(
